@@ -1,5 +1,4 @@
 """The input / output functions related to file system."""
-from datetime import datetime
 from pathlib import Path
 from typing import Dict, Any
 
@@ -12,6 +11,16 @@ from tifffile import TiffWriter
 
 import pdfstream.data
 from pdfstream.vend.loaddata import load_data
+import logging
+import sys
+
+logging.basicConfig(
+    level=logging.INFO,
+    format="[%(asctime)s | %(levelname)s] %(message)s",
+    handlers=[
+        logging.StreamHandler(sys.stdout)
+    ]
+)
 
 
 def load_ai_from_poni_file(poni_file: str) -> pyFAI.AzimuthalIntegrator:
@@ -77,9 +86,7 @@ def _str_none(dct: Dict[str, Any]) -> Dict[str, Any]:
 
 def server_message(msg: str):
     """Print a message to a uniform format of server message."""
-    if not pdfstream.data.QUIET:
-        t = datetime.now().strftime("%x %X")
-        print("[{}] {}".format(t, msg))
+    return logging.info(msg)
 
 
 def quiet():
