@@ -11,10 +11,10 @@ import pdfstream.transformation.cli as cli
     "parallel, plot_setting",
     [(False, None), (True, "OFF")]
 )
-def test_transform(db, parallel, plot_setting):
+def test_transform(test_data, parallel, plot_setting):
     with TemporaryDirectory() as temp_dir:
         dcts = cli.transform(
-            db["Ni_gr_file"], db["Ni_chi_file"],
+            test_data["Ni_gr_file"], test_data["Ni_chi_file"],
             plot_setting=plot_setting, output_dir=temp_dir, parallel=parallel, test=True
         )
         plt.close()
